@@ -11,3 +11,10 @@ test_that("arguments", {
   expect_snapshot(translate_args(normal %>% set_engine("flexsurv")))
   expect_snapshot(translate_args(dist_v %>% set_engine("flexsurv")))
 })
+
+test_that("check_args() works", {
+  skip_if_not_installed("parsnip", "1.2.1.9001")
+
+  # Here for completeness, no checking is done
+  expect_true(TRUE)
+})
